<?xml version="1.0" encoding="UTF-8"?>
<!-- This is a simple XSLT style sheet to present an .xvreport (XMLVendReport)
 in a friendly HTML format for instant visual feedback. It only displays raw message content 
 on elements that have errors associated with them.
 
 Authors: Alexander Hartner, Dawid Loubser (www.solms.co.za)
 Version: 0.1
-->

<xsl:stylesheet version="1.0" 
    xmlns:xvend="http://www.nrs.eskom.co.za/XMLVend/2004/testReport"  
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output encoding="UTF-8" indent="yes" method="html"/>

	<xsl:template match="xvend:testreport">
		<html>
		    <head>
		        <title>XMLVend Test Report</title>
		        <style type="text/css">
		        <![CDATA[
		            h1
		            {
		                border: 1px solid grey;
		                border-width: 0 0 1px 0;
		            }
		            
		            h1 em
		            {
		                color: #336699;
		                font-weight: bolder;
		                font-style: normal;
		            }
		            
		            body
		            {
		                font-family: arial, sans-serif;
		                font-size: 10pt;
		                background-color: white;
		            }
		            
		            h3
		            {
		                margin-top: 0;
		                padding-top: 0;
		            }
		            
		            h3 .passed
		            {
		                color: green;
		            }
		            
		            h3 .failed
		            {
		                color: red;
		            }
                    
                    div.clientInfo, div.serverInfo, div.timePeriod
                    {
                        background-color: #EEEEEE;
                        margin: 1em;
                        padding: 0.5em;
                        font-size: 0.9em;
                        color: #000099;
                    }
                    
                    div.clientInfo h3, div.serverInfo h3, div.timePeriod h3
                    {
                        color: grey;
                    }
                    
                    div.failSummary
                    {
                        font-size: 1.5em;
                        font-weight: bold;
                        color: red;
                        border-width: 0px 0px 1px 0px;
                        border-bottom: 1px dotted red;
                    }
                    
                    div.passSummary
                    {
                        font-size: 1.5em;
                        font-weight: bold;
                        color: green;
                        border-width: 0px 0px 1px 0px;
                        border-bottom: 1px dotted green;
                    }
                    
                    div.serviceRequest
                    {
                        border: 1px solid grey;
                        background-color: #CCEEFF;
                        margin: 1em;
                        padding: 0.5em;
                    }
                    
                    div.response
                    {
                        border: 2px solid grey;
                        background-color: #DDDDDD;
                        margin: 0.5em;
                        padding: 0.5em;
                    }
                    
                    div.xmlData
                    {
                        color: #666699;
                        border: none;
                        font-family: "Courier New", courier, fixed;
                        margin: 0.5em;
                        padding: 0.5em;
                    }
                    
                    div.error
                    {
                        border: 1px dashed red;
                        background-color: #FFCCCC;
                        color: red;
                        margin: 0.25em;
                        padding: 0.25em;
                    }
                    
                    div.label
                    {
                        float: left;
                        clear: left;
                        width: 15%;
                        color: black;
                        border-bottom: 1px solid white;
                    }
                    
                    div.timeStamp
                    {
                        color: blue;
                        font-family: "Courier New", monospace;
                    }
                    
                    div.footer
                    {
                        border-top: 2px solid grey;
                        color: grey;
                        margin: 1em;
                        font-size: 0.75em;
                        padding: 0.5em;
                    }
		        ]]>
		        </style>
		    </head>
		    <body>
		        <h1><em>XMLVend</em> Protocol Conformance Test Report</h1>			
				<xsl:apply-templates/>
				<div class="footer">
				    <strong>XMLVend Protocol Conformance Report</strong> generated using 
				    <em>xvreport2html</em> (developed by <a href="http://www.solms.co.za/">Solms TCD</a>).
				</div>
		    </body>
		</html>
	</xsl:template>
	
	<!-- Service Request -->
	<xsl:template match="xvend:serviceRequest">
	    <div class="serviceRequest">
	        <!-- Only show message if there are errors -->
	        <xsl:if test="count(./xvend:error) > 0">
	            <h3><xsl:value-of select="./xvend:serviceName"/> 
	                <span class="failed"> (Invalid)</span>
	            </h3>
	            <xsl:apply-templates select="./xvend:rawRequest/xvend:timeStamp"/>
	            <xsl:apply-templates select="./xvend:rawRequest/xvend:message"/>
	        </xsl:if>
	        <xsl:if test="count(./xvend:error) = 0">
	            <h3><xsl:value-of select="./xvend:serviceName"/> 
	                <span class="passed"> (Valid)</span>
	            </h3>
	            <xsl:apply-templates select="./xvend:rawRequest/xvend:timeStamp"/>
	        </xsl:if>
	        <xsl:apply-templates select="./xvend:error"/>
	        <xsl:apply-templates select="./xvend:response"/>
	    </div>
	</xsl:template>
	
	
	<!-- The Response -->
	<xsl:template match="xvend:response">
	    <div class="response">
		    <!-- Only show message if there are errors -->
	        <xsl:if test="count(./xvend:error) > 0">
       	        <h3>Server Response 
       	            <span class="failed"> (Invalid)</span>
       	        </h3>
	            <xsl:apply-templates select="./xvend:rawResponse/xvend:timeStamp"/>
	            <xsl:apply-templates select="./xvend:rawResponse/xvend:message"/>
	        </xsl:if>
	        <xsl:if test="count(./xvend:error) = 0">
	            <h3>Server Response 
	                <span class="passed"> (Valid)</span>
	            </h3>
	            <xsl:apply-templates select="./xvend:rawResponse/xvend:timeStamp"/>
	        </xsl:if>
   	        <xsl:apply-templates select="./xvend:error"/>
	    </div>
	</xsl:template>
	
	
	<xsl:template match="xvend:timeStamp">
	    <div class="timeStamp">
	        <xsl:value-of select="."/>
	    </div>
	</xsl:template>
	
	
	<xsl:template match="xvend:message">
	    <div class="xmlData">
        	    <xsl:value-of select="."/>
        	</div>
	</xsl:template>
	
	
	<xsl:template match="xvend:error">
	    <div class="error">
	        <h3>Error</h3>
	        <xsl:value-of select="."/>
	    </div>
	</xsl:template>


	<xsl:template match="xvend:client">
		<div class="clientInfo">
		    <h3>Client
		        <xsl:if test="count(../xvend:serviceRequest/xvend:error) = 0">
		            <span class="passed">(Passed test)</span>
		        </xsl:if>
		        <xsl:if test="count(../xvend:serviceRequest/xvend:error) > 0">
		            <span class="failed">(Failed test: 
		            <xsl:value-of select="count(../xvend:serviceRequest/xvend:error)"/>
		            )</span>
		        </xsl:if>
		    </h3>
		    <div class="ip"><div class="label">Network Address</div><xsl:value-of select="./xvend:ipAddess"/></div>
		    <div class="id"><div class="label">Client ID</div><xsl:value-of select="./xvend:clientId"/></div>
		</div>
	</xsl:template>


	<xsl:template match="xvend:server">
		<div class="serverInfo">
		    <h3>Server
		        <xsl:if test="count(../xvend:serviceRequest/xvend:response/xvend:error) = 0">
		            <span class="passed">(Passed test)</span>
		        </xsl:if>
		        <xsl:if test="count(../xvend:serviceRequest/xvend:response/xvend:error) > 0">
		            <span class="failed">(Failed test: 
		            <xsl:value-of select="count(../xvend:serviceRequest/xvend:response/xvend:error)"/>
		            )</span>
		        </xsl:if>
		    </h3>		    
		    <div class="ip"><div class="label">Network Address</div><xsl:value-of select="./xvend:ipAddess"/></div>
		</div>	
	</xsl:template>


	<xsl:template match="xvend:period">
		<div class="timePeriod">
		    <h3>Test Session</h3>
		    <div class="time"><div class="label">Start</div><xsl:value-of select="./xvend:start"/></div>
		    <div class="time"><div class="label">End</div><xsl:value-of select="./xvend:end"/></div>
		    <div class="time"><div class="label">Total Requests</div><xsl:value-of select="count(../xvend:serviceRequest)"/></div>
		</div>
	</xsl:template>	
</xsl:stylesheet>