package solms.xmlvend.messagevalidator;

import solms.xmlvend.testreport.Testreport;

/**
 * A ReportValidator is responsible for validating the request and
 * response messages in a report. A "raw" report is provided to it
 * (which may already have been processed by another ReportValidator)
 * and this validator may now examine the messages (either in isolation,
 * or in the context of the other messages to test sequencing etc).
 * 
 * The Validator reports problem by adding Error obejcts the the report -
 * this is an internalised process (versus an externalised one).
 *
 * @author dawidl
 * @version 0.1 (Jul 1, 2004)
 */
public interface ReportValidator
{
    /** Produces a short description of the validator, which may be
     * used in graphical interfaces to help identify and use.
     * @return A short description, ideally 128 chars or less.
     */
    public String getDescription();
    
    
    /** Validates a report. The Validator is free to validate any aspects of the report
     * as the situation requires: Error conditions with messages are indicated by attaching
     * @link{solms.xmlvend.testreport.Error} instances to messages.
     * @param report This report currently being validated. One validator instance may 
     * (and typically will) be asked to validate several reports, so instance members should not
     * be used to retain state during validation. (e.g. Similar to Java Servlets)
     * @throws Exception ONLY if an unrecoverable error has occurred, and not to indicate 
     * validation failure(s).
     */
    public void validate(Testreport report) throws ReportValidationException;
}
