package solms.xmlvend.messagevalidator.impl;

import java.io.FileOutputStream;
import java.io.IOException;
import solms.xmlvend.messagevalidator.ReportKeyGenerator;
import solms.xmlvend.messagevalidator.ReportPersistenceManager;
import solms.xmlvend.testreport.Testreport;
import java.io.*;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.TimeZone;

import javax.xml.bind.JAXBContext;
import javax.xml.bind.Marshaller;

/**
 * Manages reports in a directory on a filesystem. Uses the unique report keys
 * for directory names within a global output directory, and writes files based
 * on the report period start date/time
 *
 * @author dawidl
 * @version 0.1 (Jul 2, 2004)
 */
public class FileReportPersistenceManager implements ReportPersistenceManager
{
    private File baseDir;
    private ReportKeyGenerator keyMaker;
    private SimpleDateFormat fmt;
    private static String extension = ".xvreport";
    
    /** Creates an instance for a perticular directory */
    public FileReportPersistenceManager(File baseDir) throws IOException
    {
        this.baseDir = baseDir;            
        keyMaker = new ReportKeyGeneratorImpl();
        
        // Date format for geenrating report names
        fmt = new SimpleDateFormat("yyyyMMdd-HHmmss");
    }
    
    
    /* (non-Javadoc)
     * @see solms.xmlvend.messagevalidator.ReportPersistenceManager#persist(solms.xmlvend.testreport.Testreport)
     */
    public void persist(Testreport report) throws Exception
    {
        // Get key (dirname)
        String key = keyMaker.generateKey(report);
        
        // Check if directory for this report exists, otherwise create it
        File reportDir = new File(baseDir,key);
        if (!reportDir.exists())
        {
            reportDir.mkdirs();
        }
        
        // Generate filename
        String name = generateReportName(report);
        String fileName = name + extension;
        File reportFile = new File(reportDir, fileName);
        
        // Handle the case of having duplicate file name(s)
        // e.g. two empty reports for same client/server.
        
        /* This may be inconvenient - to enable again, uncomment below:
        while (reportFile.exists())
        {
            name = name + "_dupl";
            fileName = name + extension;
            reportFile = new File(reportDir, fileName);
        }
        */
        
        // Use JAXB to write to the file
        JAXBContext mct = JAXBContext.newInstance("solms.xmlvend.testreport");
        Marshaller m = mct.createMarshaller();
        m.setProperty( Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE );
        m.marshal(report, new FileOutputStream(reportFile));
        System.out.println(" Wrote report: " + reportFile.toString());
    }
    
    
    /** Generates a date-based name, useful to use for writing to file. This date is based
     * on the starting period of the report itself (usually the first message in test session).
     */
    public String generateReportName(Testreport report)
    {
        try
        {
            TimeZone tz = TimeZone.getDefault();
            Calendar start = (Calendar)report.getPeriod().getStart().clone();
            start.setLenient(true);

            // Adjust for timezone
            // This must be done manually, because the date we get from XML (wsi log)
            // has no time zone information.
            start.add(Calendar.MILLISECOND, tz.getRawOffset() * -1);            
            
            // Format
            String name = fmt.format(start.getTime());
            return name;
        }
        catch (Exception e)
        {
            return "unknown-date";
        }
    }

}
