package solms.xmlvend.messagevalidator.util;

import java.util.Calendar;
import java.util.Comparator;

/**
 * Compares two java.util.Calendar objects. Switchable ordering. 
 *
 * @author dawidl
 * @version 0.1 (Jul 1, 2004)
 */
public class CalendarComparator implements Comparator
{
    public CalendarComparator()
    {
        // Default Constructor
    }
    
    
    /* (non-Javadoc)
     * @see java.util.Comparator#compare(java.lang.Object, java.lang.Object)
     */
    public int compare(Object arg0, Object arg1)
    {
        Calendar c1 = null;
        Calendar c2 = null;
        try
        {
            // Cast to calendars
            c1 = (Calendar)arg0;
            c2 = (Calendar)arg1;
            
            // Check upfront for equality (doing it both ways in this weird
            // way, as it also implicitly checks for null values.
            if (c1.equals(c2) && c2.equals(c1))
            {
                return 0;
            }
        }
        catch (Exception e)
        {
            return 0;
        }
        
        // Simply convert to single number (milliseceonds since epoch) and compare
        long c1ms = c1.getTimeInMillis();
        long c2ms = c2.getTimeInMillis();
        
        // Use nested unary operator
        return ((c1ms == c2ms) ? 0 : (c1ms > c2ms ? -1 : 1)) * order;
    }
    
    /** Sets order to ascending (default)
     * 
     */
    public void setAscendingOrder()
    {
        order = -1;
    }
    
    /** Sets order to descending
     * 
     */
    public void setDescendingOrder()
    {
        order = 1;
    }
    
    // Indicates ordering
    private int order = -1;

}
