package solms.xmlvend.messagevalidator.util;

import java.io.File;
import java.io.FileFilter;

/**
 * Simple file filter for XMLVend Reports. Currently only based on
 * file name (.xvreport extension) though this should be extended
 * to glance at the contents of the file, and choose on the basis of that.
 * (e.g. start tag + namespace)
 *
 * @author dawidl
 * @version 0.1 (Jul 5, 2004)
 */
public class XVReportFileFilter implements FileFilter
{
    // Standard XMLVend Report File Extension
    public static final String FILE_EXTENSION = ".xvreport";
    
    public boolean accept(File file)
    {
        // Check if we can read the given file
        if (file == null || !file.canRead())
        {
            return false;
        }
        
        // Return true for directories (required for recursive traversal)
        if (file.isDirectory())
            return true;
        
        // Check if name ends with extension
        return file.getName().endsWith(FILE_EXTENSION);
    }

}
