package solms.xmlvend.messagevalidator.validators;

import java.util.Iterator;
import java.util.List;

import solms.xmlvend.messagevalidator.ReportValidationException;
import solms.xmlvend.messagevalidator.ReportValidator;
import solms.xmlvend.testreport.ObjectFactory;
import solms.xmlvend.testreport.Response;
import solms.xmlvend.testreport.SequenceError;
import solms.xmlvend.testreport.ServiceRequest;
import solms.xmlvend.testreport.Testreport;

/**
 * This validator validates message sequences. It is currently a simple
 * implementation that, at this stage, checks only for request-response
 * sequences, and in particular, whether a request does have a response.
 * 
 * It could be extended to check sequences across sets of messages, which
 * would require awareness of XMLVend Protocol and Business rules.
 *
 * @author dawidl
 * @version 0.1 (Jul 4, 2004)
 */
public class MessageSequenceValidator implements ReportValidator
{
    /**
     * @see solms.xmlvend.messagevalidator.ReportValidator#getDescription()
     */
    public String getDescription()
    {
        return description;
    }

    
    /** Cycles through all requests in a report sequentially, checking for responses.
     * @see solms.xmlvend.messagevalidator.ReportValidator#validate(solms.xmlvend.testreport.Testreport)
     */
    public void validate(Testreport report) throws ReportValidationException
    {
        // Check validity of argument
        if (report == null)
            throw new ReportValidationException("Invalid (null) report, cannot validate.");
        
        List requests = report.getServiceRequest();
        if (requests == null) return;
        
        // Cycle through messages, check for responses that are missing or empty
        Iterator reqs = requests.iterator();
        while (reqs.hasNext())
        {
            try
            {
                // Get the service request, try to get the response, and attach an error
                // if there is none.
                ServiceRequest s = (ServiceRequest)reqs.next();
                Response r = s.getResponse();
                if (r == null || r.getRawResponse() == null 
                        || r.getRawResponse().getMessage() == null 
                        || r.getRawResponse().getMessage().trim().length() < 1)
                {
                    ObjectFactory factory = new ObjectFactory();
                    SequenceError e = factory.createSequenceError();
                    e.setDescription("Service request has no response.");
                    s.getError().add(e);
                }
            }
            catch (Exception e)
            {
                System.out.println("MessageSequenceValidator: " + e);
            }
        }
    }
    
    // Description message
    private static String description = "Validates whether request messages have responses.";

}