package solms.xmlvend.messagevalidator.validators;

import org.xml.sax.SAXException;
import org.xml.sax.SAXParseException;
import org.xml.sax.helpers.DefaultHandler;

/**
 * Responsible for accumulating and making errors available to the
 * callign component. One instance of SOAPParserHandler will be used to validate
 * multiple documents, so no state should be retained as instance members across
 * documents. It will not (and should not), however, be used concurrently (in a multithreaded
 * scenario).
 *
 * @author dawidl
 * @version 0.2 (Jul 5, 2004)
 */
public class SOAPParserHandler extends DefaultHandler
{    
    private MultiSAXException mse;
    
    /* (non-Javadoc)
     * @see org.xml.sax.helpers.DefaultHandler#fatalError(org.xml.sax.SAXParseException)
     */
    public void fatalError(SAXParseException arg0) throws SAXException
    {
        // Record Error
        getExceptions().addException(arg0);
        
        // Bail out
        throwErrors();
    }
    
    /* (non-Javadoc)
     * @see org.xml.sax.helpers.DefaultHandler#error(org.xml.sax.SAXParseException)
     */
    public void error(SAXParseException arg0) throws SAXException
    {
        // Record Error
        getExceptions().addException(arg0);
    }
    
    
    /* (non-Javadoc)
     * @see org.xml.sax.helpers.DefaultHandler#endDocument()
     */
    public void endDocument() throws SAXException
    {
        // Bail out
        throwErrors();
    }
    
    
    /* (non-Javadoc)
     * @see org.xml.sax.helpers.DefaultHandler#startDocument()
     */
    public void startDocument() throws SAXException
    {
        // Kill reference to any existing exceptions
        mse = null;
    }
    
    
    /** This method throws all errors accumulated
     * up to this point, otherwise does nothing.
     */
    public void throwErrors() throws SAXException
    {
        throw getExceptions();
    }
    
    
    /** Creates the MultiSAXException if necessary, and returns it
     * 
     * @return
     */
    private MultiSAXException getExceptions()
    {
        if (mse == null)
            mse = new MultiSAXException();
        return mse;
    }
}
